@@ -109,7 +109,7 @@ void RocsGraphFileFormatPlugin::readFile()
                 else if (dataLine.startsWith(QLatin1String("DataStructurePlugin :"))) {
                     // set plugin by unique plugin identifier
                     QString pluginIdentifier = dataLine.section(' ', 2);
-                    document->setDataStructurePlugin(pluginIdentifier);
+                    document->setBackend(pluginIdentifier);
                 } else if (!dataLine.isEmpty()) {
                     break; // go to the last if and finish populating.
                 }
@@ -135,8 +135,11 @@ void RocsGraphFileFormatPlugin::readFile()
             identifier.remove(']');
             int tmpDataTypeId = identifier.toInt();
             if (tmpDataTypeId != 0) { // if == 0, this is default and default is automatically created
-                kDebug() << "Could not register data type with identifier " << tmpDataTypeId << ", it is already in use.";
                 tmpDataTypeId = document->registerDataType(QString(), identifier.toInt());
+                if (tmpDataTypeId != identifier.toInt()) {
+                    kWarning() << "Could not register already used data type << " << identifier.toInt()
+                             << ": use identifier " << tmpDataTypeId << " instead.";
+                }
             }
             DataTypePtr tmpDataType = document->dataType(tmpDataTypeId);
 
@@ -148,9 +151,11 @@ void RocsGraphFileFormatPlugin::readFile()
                     // remove rocs_ prefix
                     tmpDataType->setIcon(iconString.remove("rocs_"));
                 } else if (dataLine.startsWith(QLatin1String("Properties :"))) {
-                    QStringList properties = dataLine.section(' ', 2).split(",");
+                    QStringList properties = dataLine.section(' ', 2).split(',');
                     foreach(const QString& property, properties) {
-                        tmpDataType->addProperty(property.section('=',0,0),property.section('=',1));
+                        if (!property.isEmpty()) {
+                            tmpDataType->addProperty(property.section('=',0,0),property.section('=',1));
+                        }
                     }
                 } else if (dataLine.startsWith(QLatin1String("Color :")))     tmpDataType->setDefaultColor(QColor(dataLine.section(' ', 2)));
                 else if (!dataLine.isEmpty())               break;  // go to the last if and finish populating.
@@ -163,8 +168,11 @@ void RocsGraphFileFormatPlugin::readFile()
             identifier.remove(']');
             int tmpPointerTypeId = identifier.toInt();
             if (tmpPointerTypeId != 0) { // if == 0, this is default and default is automatically created
-                kDebug() << "Could not register pointer type with identifier " << tmpPointerTypeId << ", it is already in use.";
                 tmpPointerTypeId = document->registerPointerType(QString(), identifier.toInt());
+                if (tmpPointerTypeId != identifier.toInt()) {
+                    kWarning() << "Could not register already used pointer type << " << identifier.toInt()
+                             << ": use identifier " << tmpPointerTypeId << " instead.";
+                }
             }
             PointerTypePtr tmpPointerType = document->pointerType(tmpPointerTypeId);
 
@@ -174,12 +182,23 @@ void RocsGraphFileFormatPlugin::readFile()
                     tmpPointerType->setName(dataLine.section(' ', 2));
                 } else if (dataLine.startsWith(QLatin1String("Color :"))) {
                     tmpPointerType->setDefaultColor(QColor(dataLine.section(' ', 2)));
+                } else if (dataLine.startsWith(QLatin1String("Direction :"))) {
+                    if (dataLine.section(' ', 2) == "bidirectional") {
+                        tmpPointerType->setDirection(PointerType::Bidirectional);
+                    } else if (dataLine.section(' ', 2) == "unidirectional") {
+                        tmpPointerType->setDirection(PointerType::Unidirectional);
+                    }
+                    else {
+                        kWarning() << "Direction unset, use default direction of this data type backend.";
+                    }
                 } else if (dataLine.startsWith(QLatin1String("LineStyle :"))) {
                     tmpPointerType->setLineStyle(Qt::PenStyle(dataLine.section(' ', 2).toInt()));
                 } else if (dataLine.startsWith(QLatin1String("Properties :"))) {
-                    QStringList properties = dataLine.section(' ', 2).split(",");
+                    QStringList properties = dataLine.section(' ', 2).split(',');
                     foreach(const QString& property, properties) {
-                        tmpPointerType->addProperty(property.section('=',0,0),property.section('=',1));
+                        if (!property.isEmpty()) {
+                            tmpPointerType->addProperty(property.section('=',0,0),property.section('=',1));
+                        }
                     }
                 } else if (!dataLine.isEmpty()) {
                     break;  // go to the last if and finish populating.
@@ -269,7 +288,9 @@ void RocsGraphFileFormatPlugin::readFile()
         else if (str.contains(':')) {
             QString propertyName = str.section(':', 0, 0).trimmed();
             QString propertyValue = str.section(':', 1, 1).trimmed();
-            tmpObject->setProperty(propertyName.toUtf8() , propertyValue);
+            if (!propertyName.isEmpty()) {
+                tmpObject->setProperty(propertyName.toUtf8() , propertyValue);
+            }
         }
     }
     setGraphDocument(document);
@@ -333,10 +354,16 @@ QString RocsGraphFileFormatPlugin::serialize(const Document &document)
             properties.append(property + QString('=') + document.pointerType(pointerTypeIdentifier)->propertyDefaultValue(property).toString());
         }
 
+        // set direction identifier
+        QString direction = (document.pointerType(pointerTypeIdentifier)->direction() == PointerType::Bidirectional)
+            ? "bidirectional"
+            : "unidirectional";
+
         d->_buffer += QString("[PointerType %1]").arg(QString::number(pointerTypeIdentifier)) % QChar('\n')
             % QString("Name : ") % document.pointerType(pointerTypeIdentifier)->name() % QChar('\n')
             % QString("Color : ") % document.pointerType(pointerTypeIdentifier)->defaultColor().name() % QChar('\n')
             % QString("LineStyle : ") % QString::number(document.pointerType(pointerTypeIdentifier)->lineStyle()) % QChar('\n')
+            % QString("Direction : ") % direction % QChar('\n')
             % QString("Properties : ") % properties.join(QChar(','))
             % QChar('\n');
         d->_buffer += QChar('\n');
